@@ -1,5 +1,5 @@
 `text.ordiplot`  <-
-    function (x, what, labels, select, arrows = FALSE, ...)
+    function (x, what, labels, select, arrows = FALSE, length = 0.05, ...)
 {
     sco <- scores(x, what)
     if (!missing(labels))
@@ -12,7 +12,7 @@
         sco <- sco * ordiArrowMul(sco)
     }
     if (arrows) {
-        arrows(0, 0, sco[,1], sco[,2], ...)
+        arrows(0, 0, sco[,1], sco[,2], length = length, ...)
         sco <- ordiArrowTextXY(sco, rownames(sco), rescale = FALSE)
     }
     text(sco, labels = rownames(sco), ...)
