@@ -10,7 +10,8 @@
     METHODS <- c("manhattan", "euclidean", "canberra", "bray", # 4
                  "kulczynski", "gower", "morisita", "horn", #8
                  "mountford", "jaccard", "raup", "binomial", "chao", #13
-                 "altGower", "cao", "mahalanobis", "clark", "chisq", "chord") #19
+                 "altGower", "cao", "mahalanobis", "clark", "chisq", "chord", #19
+		 "hellinger", "aitchison", "robust.aitchison") # 22
     method <- pmatch(method, METHODS)
     inm <- METHODS[method]
     if (is.na(method))
@@ -26,14 +27,17 @@
     if (!(is.numeric(x) || is.logical(x)))
         stop("input data must be numeric")
     if (!method %in% c(1,2,6,16,18) && any(rowSums(x, na.rm = TRUE) == 0))
-        warning("you have empty rows: their dissimilarities may be meaningless in method ",
-                dQuote(inm))
+        warning("you have empty rows: their dissimilarities may be
+                 meaningless in method ",
+                 dQuote(inm))
     ## 1 manhattan, 2 euclidean, 3 canberra, 6 gower, 16 mahalanobis, 19 chord
-    if (!method %in% c(1,2,3,6,16,19) && any(x < 0, na.rm = TRUE))
-        warning("results may be meaningless because data have negative entries in method ",
-                dQuote(inm))
+    if (!method %in% c(1,2,3,6,16,19,20) && any(x < 0, na.rm = TRUE))
+        warning("results may be meaningless because data have negative entries
+                 in method ",
+                 dQuote(inm))
     if (method %in% c(11,18) && any(colSums(x) == 0))
-        warning("data have empty species which influence the results in method ",
+        warning("data have empty species which influence the results in
+                 method ",
                 dQuote(inm))
     if (method == 6) # gower, but no altGower
         x <- decostand(x, "range", 2, na.rm = TRUE, ...)
@@ -41,8 +45,10 @@
         x <- veganMahatrans(scale(x, scale = FALSE))
     if (method == 18) # chisq
         x <- decostand(x, "chi.square")
-    if (method == 19) # chord
-        x <- decostand(x, "normalize")
+    if (method == 21)  # aitchison
+        x <- decostand(x, "clr", ...)  # dots to pass possible pseudocount
+    if (method == 22)  # robust.aitchison
+        x <- decostand(x, "rclr") # No pseudocount for rclr
     if (binary)
         x <- decostand(x, "pa")
     N <- nrow(x)
@@ -55,6 +61,16 @@
     d[d < ZAP] <- 0
     if (any(is.na(d)))
         warning("missing values in results")
+    ## add attribute maxdist: the maximum value of the distance function
+    attr(d, "maxdist") <-
+        if(method %in% c(3,4,5,7,8,10,11,13,17)) # index in 0..1
+            1
+        else if (method %in% c(19,20)) # chord, hellinger
+            sqrt(2)
+        else if (method == 9) # Mountford
+            log(2)
+        else # no fixed upper limit
+            NA
     attr(d, "Size") <- N
     attr(d, "Labels") <- dimnames(x)[[1]]
     attr(d, "Diag") <- diag
